@@ -25,3 +25,6 @@
 # **************************************************************************
 
 from .viewer_cltomo import XmippCLTomoViewer, XmippProtTsFlexAlignViewer
+from .viewer_resolution_local_monotomo import XmippMonoTomoViewer
+from .viewer_phantom_create import XmippPhantomSubtomoViewer
+
